From: Thomas Haller <thaller@redhat.com>
Date: Fri, 15 Apr 2022 13:29:49 +0200
Subject: [PATCH] build: avoid building check-direct with --disable-static

"check-direct" needs to statically link with the libraries, because
it wants to test internal ABI, which is hidden in the share libraries.
When configuring with "--disable-static", static libs are not build
and the test tool cannot be build.

Just skip the test in that case.

https://github.com/thom311/libnl/issues/306
--- a/Makefile.am
+++ b/Makefile.am
@@ -984,8 +984,10 @@ tests_check_all_LDADD = \
 	$(NULL)
 
 if WITH_CHECK
+if ENABLE_STATIC
 check_programs += tests/check-direct
 endif
+endif
 
 tests_check_direct_SOURCES = \
 	tests/check-direct.c \
--- a/configure.ac
+++ b/configure.ac
@@ -107,6 +107,8 @@ else
     AC_CHECK_LIB([pthread], [pthread_mutex_lock], [], AC_MSG_ERROR([libpthread is required]))
 fi
 
+AM_CONDITIONAL([ENABLE_STATIC], [test "$enable_static" != "no"])
+
 AC_ARG_ENABLE([debug],
 	AS_HELP_STRING([--disable-debug], [Do not include debugging statements]),
 	[enable_debug="$enableval"], [enable_debug="yes"])

